FactorySettings

Struct FactorySettings 

pub struct FactorySettings<CustomerData = RawCustomerData, VendorUsage = RawVendorUsage>
where CustomerData: FactorySettingsCustomerData, VendorUsage: FactorySettingsVendorUsage,
{ pub boot_configuration: BootConfiguration, pub usb_id: UsbId, pub debug_access: DebugAccess, pub vendor_usage: VendorUsage, pub secure_boot_configuration: SecureBootConfiguration, pub prince_configuration: PrinceConfiguration, pub prince_subregions: [PrinceSubregion; 3], pub rot_fingerprint: Sha256Hash, pub customer_data: CustomerData, pub seal: bool, /* private fields */ }

Fields

boot_configuration: BootConfigurationusb_id: UsbIddebug_access: DebugAccessvendor_usage: VendorUsagesecure_boot_configuration: SecureBootConfigurationprince_configuration: PrinceConfigurationprince_subregions: [PrinceSubregion; 3]rot_fingerprint: Sha256Hash

Fingerprint of allowed root certificates for signed firmware update process.

Called “ROTKH” for “root of trust key table hash” in vendor documentation.

There can be up to four root certificate authorities; each have a “fingerprint” (cf. elsewhere), the fingerprint here is the SHA256 hash of the concatenation of these fingerprints. Due to this construction, each SB2.1 firmware container needs to contain all the root certificates (plus possibly a certificate chain to the authority actually signing the firmware).

customer_data: CustomerData

224 bytes that the customer can use.

seal: bool

Setting this to true will calculate the SHA256 automatically for sha256_hash.

Implementations

Source

impl<CustomerData, VendorUsage> FactorySettings<CustomerData, VendorUsage>
where CustomerData: FactorySettingsCustomerData, VendorUsage: FactorySettingsVendorUsage,

pub fn to_bytes(&mut self) -> Result<[u8; 512]>