BootCommand

Enum BootCommand 

pub enum BootCommand {
    Nop,
    Tag {
        last: bool,
        tag: u32,
        flags: u32,
        cipher_blocks: u32,
    },
    Load {
        address: u32,
        data: Vec<u8>,
    },
    Fill {
        address: u32,
        bytes: u32,
        pattern: u32,
    },
    EraseAll,
    EraseRegion {
        address: u32,
        bytes: u32,
    },
    CheckSecureFirmwareVersion {
        version: u32,
    },
    CheckNonsecureFirmwareVersion {
        version: u32,
    },
}

Variants



Nop



Tag

Fields

last: bool
tag: u32
flags: u32
cipher_blocks: u32


Load

Fields

address: u32
data: Vec<u8>


Fill

See ELFTOSB document for explanations of what is supposed to happen when address is not on a word boundary.

In any case, if a byte is supposed to be repeated, it must be replicated four times in the pattern, e.g. “fill with 0xF1” => pattern = 0xf1f1_f1f1.

Fields

address: u32
bytes: u32
pattern: u32


EraseAll



EraseRegion

Fields

address: u32
bytes: u32


CheckSecureFirmwareVersion

Fields

version: u32


CheckNonsecureFirmwareVersion

Fields

version: u32

Implementations

Source

impl BootCommand

pub fn to_bytes(&self) -> Vec<u8>

pub fn from_bytes(bytes: &[u8]) -> IResult<&[u8], Self, ()>