pub enum SingleBootCommandDescription {
Erase {
start: u32,
end: u32,
},
Load {
file: String,
src: u32,
dst: u32,
len: Option<u32>,
},
CheckNonsecureFirmwareVersion {
version: u32,
},
CheckSecureFirmwareVersion {
version: u32,
},
}Expand description
Commands used to define SB2.1 files
Currently, we only need to erase and load (partial) files.
Example
Since there does not seem to exit a command to enter the bootloader, but a corrupt / missing firmware makes the MCU enter the bootloader, one way to do so is the following specification, which erases the first flash page.
ⓘ
[[commands]]
cmd = "Erase"
start = 0
end = 512Example
To securely flash firmware, it is advised to write the first page last, so that if flashing goes wrong or is interrupted, the MCU stays in the bootloader on next boot.
ⓘ
[[commands]]
cmd = "Erase"
start = 0
end = 0x8_9800
[[commands]]
# write firmware, skipping first flash page
cmd = "Load"
file = "example.sb2"
src = 512
dst = 512
[[commands]]
# write first flash page of firmware
cmd = "Load"
file = "example.sb2"
len = 512Variants
Erase
Maps to BootCommand::EraseRegion, but start and end are given in bytes.
Load
Load (part) of the data reference in source to flash.
The syntax is such that if source data and destination flash were slices
src: &[u8] and dst: &mut [u8], this command would do:
ⓘ
let src_len = src.len() - cmd.src;
let len = cmd.len.unwrap_or(src_len);
dst[cmd.dst..][..len].copy_from_slice(&src[cmd.src..][..len]);Fields
CheckNonsecureFirmwareVersion
CheckSecureFirmwareVersion