pub struct Version {
pub major: u16,
pub minor: u16,
pub patch: u16,
}Expand description
Version of a firmware.
The version must be encoded in certain places. To make the API somewhat useable (but admittedly also a bit weirder), we use:
- 10 bits for major
- 16 bits for minor
- 6 bits for patch
which gives offsets of 22 bits for major and 6 bits for minor in the u32.
Further, the minor version is at times interpreted as a “calver” encoding days since 2020-01-01. This is optional to use, “semver” works as well.
Fields
major: u16minor: u16patch: u16Implementations
Sourceimpl Version
impl Version
Sourcepub fn minor_as_date(&self) -> NaiveDate
pub fn minor_as_date(&self) -> NaiveDate
The minor version component in its interpretation as days since 2020-01-01
pub fn timestamp_micros(&self) -> u64